/***************************************************************
                 ___ _     _    __  __
                | _ ) |___| |__|  \/  |__ _ _ _
                | _ \ / _ \ '_ \ |\/| / _` | ' \  v3.6
                |___/_\___/_.__/_|  |_\__,_|_||_| 
                                                   01 March 2000

by Peter Houston <houston.graphics@iname.com>
                < http://welcome.to/HoustonGraphics >
                < http://members.xoom.com/HoustonGraph >
based on Blob Man model by Govert Zoethout <zoethout@gmx.net>
                < http://victorian.fortunecity.com/dada/507/ >

Refer to blob_man.txt for full usage details.

****************************************************************/

#local Blob_Man_Version = version;
#version 3.1;

/***************************************************************
Blob_Man Macro
- - - - - - - - 
Usage : Declare Pose Arrays before calling this macro, 
        example can be found in default.pos file.
        
Blob_Man( PoseNo , Build , Face_Map , Eye_Colour , Right_Lid , Left_Lid , 
          HairStyle , Hair_Col , Right_Hand , Left_Hand )        

PoseNo     = Array Entry for pose required
Build      = Blob Threshold Level    - standard: 0.5
Face_Map   = Image Map used for face 0= No Map 1-5 is number of png file.
             Name of file is bmface#.png where # is Face_Map Number, uses aplha channel.
Eye_Colour = Eye Iris Colour <r,g,b>
Right_Lid  = Right Eye Lid Position  (range : 0-Open to 1-Closed)      - standard: 0
Left_Lid   = Left Eye Lid Position  (range : 0-Open to 1-Closed)       - standard: 0
HairStyle  = Array Entry for Hair Style required
Hair_Col   = Hair Colour (<r,g,b>)
Left_Hand  = Array Entry for Hand Position to overide standard position as defined 
             by the Pose Definition, 0=Pose Definition
Right_Hand = Array Entry for Hand Position to overide standard position as defined 
             by the Pose Definition, 0=Pose Definition                                                        

****************************************************************/
#macro Blob_Man(PoseNo,Build,Face_Map,Eye_Colour,Right_Lid,Left_Lid,HairStyle,Hair_Col,Right_Hand,Left_Hand)

    #local RA_S2E     = Pose_1[PoseNo][0];
    #local RA_E2W     = Pose_1[PoseNo][1];
    #local LA_S2E     = Pose_1[PoseNo][2];
    #local LA_E2W     = Pose_1[PoseNo][3];
    #local RL_H2K     = Pose_1[PoseNo][4];
    #local RL_K2A     = Pose_1[PoseNo][5];
    #local LL_H2K     = Pose_1[PoseNo][6];
    #local LL_K2A     = Pose_1[PoseNo][7];
    #local RH_Rot     = Pose_1[PoseNo][8];
    #local LH_Rot     = Pose_1[PoseNo][9];
    #local RF_Rot     = Pose_1[PoseNo][10];
    #local LF_Rot     = Pose_1[PoseNo][11];

    #local Eye_Rot    = Pose_2[PoseNo][0];
    #local Lip_Size   = Pose_2[PoseNo][1];
    #local Head_Twist = Pose_2[PoseNo][2];
    #local Head_Tip   = Pose_2[PoseNo][3];
    #local Head_Tilt  = Pose_2[PoseNo][4];
// Use Hands defined by PoseNo if not specified in Macro Call.
    #if (Right_Hand=0)
        #local Right_Hand = Pose_2[PoseNo][5];
    #end
    #if (Left_Hand=0)
        #local Left_Hand = Pose_2[PoseNo][6];
    #end
                          
    #local Hair_Rot   = Pose_Hair_1[HairStyle][0];

    #local Hair_On    = Pose_Hair_2[HairStyle][0];
    #local Hair_Arch  = Pose_Hair_2[HairStyle][1];
    #local Hair_Thck  = Pose_Hair_2[HairStyle][2];
    #local Hair_Line  = Pose_Hair_2[HairStyle][3];
    #local Hair_LDpth = Pose_Hair_2[HairStyle][4];
    #local Hair_Wght  = Pose_Hair_2[HairStyle][5];
    #local Hair_Hght  = Pose_Hair_2[HairStyle][6];
    #local Hair_Length= Pose_Hair_2[HairStyle][7];
    #local Hair_Curl  = Pose_Hair_2[HairStyle][8];

    #local LF_Spread  = Pose_Hands[Left_Hand][0];
    #local LFP_Pos    = Pose_Hands[Left_Hand][1];
    #local LFR_Pos    = Pose_Hands[Left_Hand][2];
    #local LFM_Pos    = Pose_Hands[Left_Hand][3];
    #local LFI_Pos    = Pose_Hands[Left_Hand][4];
    #local LFT_Pos    = Pose_Hands[Left_Hand][5];
    #local RF_Spread  = Pose_Hands[Right_Hand][0];
    #local RFP_Pos    = Pose_Hands[Right_Hand][1];
    #local RFR_Pos    = Pose_Hands[Right_Hand][2];
    #local RFM_Pos    = Pose_Hands[Right_Hand][3];
    #local RFI_Pos    = Pose_Hands[Right_Hand][4];
    #local RFT_Pos    = Pose_Hands[Right_Hand][5];

    #declare BlobMan= 
        union {
            object { head( Build,Eye_Colour,Right_Lid,Left_Lid,Eye_Rot,Lip_Size,Head_Twist,Head_Tip,Head_Tilt,Face_Map ) }
            object {torso( Build,RA_S2E,RA_E2W,LA_S2E,LA_E2W,RL_H2K,RL_K2A,LL_H2K,LL_K2A ) }
            object { hand( Build,LA_S2E,LA_E2W,LH_Rot, 1,LF_Spread, LFP_Pos, LFR_Pos, LFM_Pos, LFI_Pos, LFT_Pos ) }
            object { hand( Build,RA_S2E,RA_E2W,RH_Rot,-1,RF_Spread, RFP_Pos, RFR_Pos, RFM_Pos, RFI_Pos, RFT_Pos ) }
            object { feet( Build,RL_H2K,RL_K2A,LL_H2K,LL_K2A,RF_Rot,LF_Rot ) }
            object { hair( Hair_On,Hair_Rot,Hair_Col,Hair_Arch,Hair_Thck,Hair_Line,Hair_LDpth,Hair_Wght,Hair_Hght,Hair_Length,Hair_Curl,Head_Twist,Head_Tip,Head_Tilt ) }
        }
#end

/***************************************************************
Torso Macro
- - - - - - 
Usage :

torso(build , skin , RA_S2E , RA_E2W , LA_S2E , LA_E2W ,
                     RL_H2K , RL_K2A , LL_H2K , LL_K2A  )

build  = Blob Threshold Level                        - standard: 0.5
skin   = Skin color (<r,g,b>)                        - standard: <.9,.7,.6>
RA_S2E = Right Arm Shoulder to Elbow rotation vector - standard: <0,0,0>
RA_E2W = Right Arm Elbow to Wrist rotation vector    - standard: <0,0,0>
LA_S2E = Left Arm Shoulder to Elbow rotation vector  - standard: <0,0,0>
LA_E2W = Left Arm Elbow to Wrist rotation vector     - standard: <0,0,0>
RL_H2K = Right Leg Hip to Knee rotation vector       - standard: <0,0,0>
RL_K2A = Right Leg Knee to Ankle rotation vector     - standard: <0,0,0>
LL_H2K = Right Leg Hip to Knee rotation vector       - standard: <0,0,0>
LL_K2A = Right Leg Knee to Ankle rotation vector     - standard: <0,0,0>

*****************************************************************/

#macro torso(build,RA_S2E,RA_E2W,LA_S2E,LA_E2W,RL_H2K,RL_K2A,LL_H2K,LL_K2A)

    #local UpperarmLength=11;
    #local ForearmLength =9;
    #local ThighLength   =14;
    #local CalfLength    =17;

    #local R_Elbow=vrotate(<0,-UpperarmLength,0>,RA_S2E);
    #local R_Wrist=vrotate(<0,-ForearmLength,0> ,RA_E2W);
    #local L_Elbow=vrotate(<0,-UpperarmLength,0>,LA_S2E);
    #local L_Wrist=vrotate(<0,-ForearmLength,0> ,LA_E2W);

    #local R_Knee =vrotate(<0,-ThighLength,0>,RL_H2K);
    #local R_Ankle=vrotate(<0,-CalfLength,0> ,RL_K2A);
    #local L_Knee =vrotate(<0,-ThighLength,0>,LL_H2K);
    #local L_Ankle=vrotate(<0,-CalfLength,0> ,LL_K2A);

    #local R_Upperarm=transform {rotate RA_S2E translate <-9,-UpperarmLength,1>}
    #local L_Upperarm=transform {rotate LA_S2E translate < 9,-UpperarmLength,1>}
    #local R_Forearm =transform {rotate RA_E2W translate R_Elbow translate <-9,-UpperarmLength,1>}
    #local L_Forearm =transform {rotate LA_E2W translate L_Elbow translate < 9,-UpperarmLength,1>}

    #local R_Thigh=transform {rotate RL_H2K translate <-4,-29,0>}
    #local L_Thigh=transform {rotate LL_H2K translate < 4,-29,0>}
    #local R_Calf =transform {rotate RL_K2A translate R_Knee translate <-4,-29,0>}
    #local L_Calf =transform {rotate LL_K2A translate L_Knee translate < 4,-29,0>}
    union {
        union {
            #if (BM_Torso_Mass>0)
                blob {
                    threshold build-.3
// Neck & Spine
                    #local Loop=0;
                    #while (Loop>-29)
                        sphere{0,2,2 translate<0,Loop-3,sin((Loop+2)*pi/(4+abs(Loop)/4))*(.25+abs(Loop/15))+1>}
                        #if (mod(Loop+2,3)=0)
                            sphere{0,1,1 translate<0,Loop-3,sin((Loop+2)*pi/(4+abs(Loop)/4))*(.25+abs(Loop/15))+2.1>}
                        #end
                        #local Loop=Loop-1;
                    #end

//Shoulders & Neck
                    cylinder{<-8,-9,.5><-1,-6.75,1>,1.2,2}
                    cylinder{< 8,-9,.5><1,-6.75,1>,1.2,2}
                    cylinder{<-8,-10,1><8,-10,1>,3.2,2}
// Upper Chest
                    cylinder{<-8,-9,.5><-1,-9.5,-1.25>,1,2}
                    cylinder{<8,-9,.5><1,-9.5,-1.25>,1,2 }
                    cylinder{<-6,-10.5,-.5><6,-10.5,-.5>,2,2}
// Chest and Shoulder Blades
                    #if (BM_BodyStyle=0)
                        // Original Chest Style
                        sphere{0,4,2 scale<1.4,2,1.3> rotate x*20 translate<-2.8,-14,0> } // Right
                        sphere{0,4,2 scale<1.4,2,1.3> rotate x*20 translate< 2.8,-14,0>}  // Left 
                    #else
                        // New Chest Style
                        sphere{0,4,2.5   scale <1.4,2,1.3>   rotate x*22 translate <-2.8,-14,0>}  // Right
                        sphere{0,4,3   scale <1.4,1,1.3>   rotate x*20 rotate z*20 translate<-3,-13,-.25>} 
                        sphere{0,4,-.8 scale <1.4,2,1.3>   rotate x*20 translate <-2.8,-14,-3.5>}    
                        sphere{0,2,-2  scale <2,2.75,2>    rotate z*10 translate <-9.25,-15.25,1> rotate y*-15}                    
                        sphere{0,2,-.8 scale <2.5,1.3,.75> rotate y*45 translate <-5,-17.75,-3.5>}
                        sphere{0,3,1   scale <1.5,2,1.2>   translate <-2.8,-19,.5> }
                        sphere{0,3,1   scale <1.5,1.5,.75> translate <-2.5,-25,2> }
                    
                        sphere{0,4,2.5   scale <1.4,2,1.3>   rotate x*22  translate < 2.8,-14,0>} // Left
                        sphere{0,4,3   scale <1.4,1,1.3>   rotate x*20  rotate z*-20 translate< 3,-13,-.25>} 
                        sphere{0,4,-.8 scale <1.4,2,1.3>   rotate x*20  translate < 2.8,-14,-3.5>} 
                        sphere{0,2,-2  scale <2,2.75,2>    rotate z*-10 translate < 9.25,-15.25,1> rotate y*15}
                        sphere{0,2,-.8 scale <2.5,1.3,.75> rotate y*-45 translate < 5,-17.75,-3.5>}
                        sphere{0,3,1   scale <1.5,2,1.2>   translate <2.8,-19,.5>}
                        sphere{0,3,1   scale <1.5,1.5,.75> translate <2.5,-25,2> }
                    #end

// Abdomen
                    sphere{0,3,2 scale<1,1,1>     translate<-1.5,-17.5,-1>}
                    sphere{0,3,2 scale<1,1,1>     translate<1.5,-17.5,-1>}
                    sphere{0,3,2 scale<1,1,1.2>   translate<-1.5,-20,-1>}
                    sphere{0,3,2 scale<1,1,1.2>   translate<1.5,-20,-1>}
                    sphere{0,3,2 scale<1,1.2,1.2> translate<-1.5,-22.5,-1.25>}
                    sphere{0,3,2 scale<1,1.2,1.2> translate<1.5,-22.5,-1.25>}
                    sphere{0,3,2 scale<1,1,1.2>   translate<-1.5,-25,-1>}
                    sphere{0,3,2 scale<1,1,1.2>   translate<1.5,-25,-1>}
// Pelvis
                    sphere{0,5,2 scale<1.2,1.6,1>  translate<0,-27,-.5> } //Front & Back
                    #if (BM_BodyStyle=0)
                        sphere{0,3,2 scale<1.4,.8,1.5> rotate z*-75 translate<-4,-28,-.5>} // Right
                        sphere{0,3,2 scale<1.4,.8,1.5> rotate z* 75 translate< 4,-28,-.5>} // Left 
                        sphere{0,3,2 scale <1.5,2,1.2> translate <-2.8,-22.5,0>} // Right
                        sphere{0,3,2 scale <1.5,2,1.2> translate < 2.8,-22.5,0>}   // Left

                    #else
                        sphere{0,3,1 scale<1.4,.8,1.5> rotate z*-75 translate<-4,-28,-.5>} // Right
                        sphere{0,3,1 scale<1.4,.8,1.5> rotate z* 75 translate< 4,-28,-.5>} // Left 
                        sphere{0,3,2 scale <1.5,2.15,1.2> translate <-2.8,-23,0>} // Right
                        sphere{0,3,2 scale <1.5,2.15,1.2> translate < 2.8,-23,0>}   // Left
                    #end
// Buttocks
                   sphere{0,3,2 scale<1.75,2,1.5> rotate x*15 translate<-3.,-29.5,1.5> } // Right
                   sphere{0,3,2 scale<1.75,2,1.5> rotate x*15 translate< 3.,-29.5,1.5>}  // Left
                }   
            #end
            #if (BM_Torso_Mass=0)
                object {nul}
            #end
            #if (BM_Torso_Mass<0)
// Object Guides
                blob {
                    threshold build-.3
                    #local Loop=0;
                    #while (Loop>-29)
                        sphere{0,Guide_Rad,2 translate<0,Loop-3,sin((Loop+2)*pi/(4+abs(Loop)/4))*(.25+abs(Loop/15))+1>}
                        #local Loop=Loop-1;
                    #end
                    cylinder{<-8,-10,1><8,-10,1>,Guide_Rad,2}
                    cylinder{<-4,0,0><4,0,0>Guide_Rad,2 translate<0,-28,-.5>}
                }
            #end
            object {Torso_Object}
//Material
            material {
                texture {Skin_Tex}
                #ifdef (Torso_IMap)
                    texture {
                        pigment {
                            image_map {
                                png Torso_IMap
                                map_type 2
                                interpolate 4
                                once
                            } 
                            rotate y*-90
                            scale 40
                            translate <0,-40,0>
                        }
                        #ifdef (Map_Finish)
                            finish {Map_Finish}
                        #end
                        #ifdef (Map_Normal)
                            normal {Map_Normal}
                        #end
                        #ifdef (Torso_BMap)
                            normal {
                                bump_map {
                                    png Torso_BMap
                                    map_type 2
                                    interpolate 4
                                    once
                                    bump_size Bump_Map_Size
                                }
                                rotate y*-90
                                scale 40
                                translate <0,-40,0>
                            }
                        #end
                    }
                #end
            }
        }
//Arms
// Upperarm - Right
        union {
            blob {
                threshold build-.3
                #if (BM_R_Upperarm_Mass>= 2)
                    cylinder{<0,0,-1>,<0,-UpperarmLength,0>,2.7,2}
                    sphere  {<0,0,-.5>3.5,2.5 scale <1,UpperarmLength*.2,1> translate <0,-UpperarmLength*.2-1.25,0>}
                #end
                #if (BM_R_Upperarm_Mass= 1)
                    cylinder{<0,0,0>,<0,-UpperarmLength,0>,2.7,2}
                #end
                #if (BM_R_Upperarm_Mass= 0)
                    sphere  {<0,0,0>.00001,0.00000001 pigment {rgbft 1}}
                #end
                #if (BM_R_Upperarm_Mass< 0)
// Object Guides
                    cylinder{<0,0,0>,<0,-UpperarmLength,0>,Guide_Rad,2}
                #end
            }
            object {Upperarm_R_Object}
            material {
                texture {Skin_Tex}
                #ifdef (Upperarm_R_IMap)
                    texture {
                        pigment {
                            image_map {
                                png Upperarm_R_IMap
                                map_type 2 
                                interpolate 4
                                once
                            }
                            scale 20
                            translate <0,-15,0>
                        }
                        #ifdef (Map_Finish)
                            finish {Map_Finish}
                        #end
                        #ifdef (Map_Normal)
                            normal {Map_Normal}
                        #end
                        #ifdef (Upperarm_R_BMap)
                            normal {
                                bump_map {
                                    png Upperarm_R_BMap
                                    map_type 2
                                    interpolate 4
                                    once
                                    bump_size Bump_Map_Size
                                }
                                scale 20
                                translate <0,-15,0>
                            }
                        #end
                    }
                #end
            }
            transform R_Upperarm
        }
// Upperarm - Left
        union {
            blob {
                threshold build-.3
                #if (BM_L_Upperarm_Mass>= 2)
                    cylinder{<0,0,-1>,<0,-UpperarmLength,0>,2.7,2}
                    sphere  {<0,0,-.5>3.5,2.5 scale <1,UpperarmLength*.2,1> translate <0,-UpperarmLength*.2-1.25,0>}
                #end
                #if (BM_L_Upperarm_Mass= 1)
                    cylinder{<0,0,0>,<0,-UpperarmLength,0>,2.7,2}
                #end
                #if (BM_L_Upperarm_Mass= 0)
                    sphere  {<0,0,0>.00001,0.0000001 pigment {rgbft 1}}
                #end
                #if (BM_L_Upperarm_Mass<0)
// Object Guides
                    cylinder{<0,0,0>,<0,-UpperarmLength,0>,Guide_Rad,2}
                #end
            }
            object {Upperarm_L_Object}
            material {
                texture {Skin_Tex}
                #ifdef (Upperarm_L_IMap)
                    texture {
                        pigment {
                            image_map {
                                png Upperarm_L_IMap
                                map_type 2 
                                interpolate 4
                                once
                            } 
                            rotate y*180
                            scale 20
                            translate <0,-15,0>
                        }
                        #ifdef (Map_Finish)
                            finish {Map_Finish}
                        #end
                        #ifdef (Map_Normal)
                            normal {Map_Normal}
                        #end
                        #ifdef (Upperarm_L_BMap)
                            normal {
                                bump_map {
                                    png Upperarm_L_BMap
                                    map_type 2
                                    interpolate 4
                                    once
                                    bump_size Bump_Map_Size
                                }
                                rotate y*180
                                scale 20
                                translate <0,-15,0>
                            }
                        #end
                    }
                #end
            }
            transform L_Upperarm
        }
// Forearm - Right
        union {
            blob {
                threshold build-.3
                #if (BM_R_Forearm_Mass>= 2)
                    cylinder{0,<0,-ForearmLength,0>,2.5,2}
                    sphere  {0,3,2 scale <1,ForearmLength*.18,1> translate <0,-ForearmLength*.18-.5,0>}
                    sphere  {0,2.75,-1.5 scale <1,3.5,1> translate <0,-ForearmLength-1,0>}
                #end
                #if (BM_R_Forearm_Mass = 1)
                    cylinder{0,<0,-ForearmLength,0>,2.5,2}
                    sphere  {0,2.75,-1.5 scale <1,3.5,1> translate <0,-ForearmLength-1,0>}
                #end
                #if (BM_R_Forearm_Mass=0)
                    sphere  {<0,0,0>.00001,0.000001 pigment {rgbft 1}}
                #end
                #if (BM_R_Forearm_Mass<0)
// Object Guides
                    cylinder{0,<0,-ForearmLength,0>,Guide_Rad,2}
                #end
            }
            object {Forearm_R_Object}
            material {
                texture {Skin_Tex}
                #ifdef (Forearm_R_IMap)
                    texture {
                        pigment {
                            image_map {
                            png Forearm_R_IMap
                            map_type 2
                            interpolate 4
                            once
                            }
                            scale 15
                            translate <0,-12,0>
                        }
                        #ifdef (Map_Finish)
                            finish {Map_Finish}
                        #end
                        #ifdef (Map_Normal)
                            normal {Map_Normal}
                        #end
                        #ifdef (Forearm_R_BMap)
                            normal {
                                bump_map {
                                    png Forearm_R_BMap
                                    map_type 2
                                    interpolate 4
                                    once
                                    bump_size Bump_Map_Size
                                }
                                scale 15
                                translate <0,-15,0>
                            }
                        #end
                    }
                #end
            }
            transform R_Forearm
        }
// Forearm - Left
        union {
            blob {
                threshold build-.3
                #if (BM_L_Forearm_Mass>= 2)
                    cylinder{0,<0,-ForearmLength,0>,2.5,2}
                    sphere  {0,3,2 scale <1,ForearmLength*.18,1> translate <0,-ForearmLength*.18-.5,0>}
                    sphere  {0,2.75,-1.5 scale <1,3.5,1> translate <0,-ForearmLength-1,0>}
                #end
                #if (BM_L_Forearm_Mass = 1)
                    cylinder{0,<0,-ForearmLength,0>,2.5,2}
                    sphere  {0,2.75,-1.5 scale <1,3.5,1> translate <0,-ForearmLength-1,0>}
                #end
                #if (BM_L_Forearm_Mass= 0)
                    sphere  {<0,0,0>.00001,0.00000001 pigment {rgbft 1}}
                #end
                #if (BM_L_Forearm_Mass< 0)
// Object Guides
                    cylinder{0,<0,-ForearmLength,0>,Guide_Rad,2}
                #end
            }
            object {Forearm_L_Object}
            material {
                texture {Skin_Tex}
                #ifdef (Forearm_L_IMap)
                    texture {
                        pigment {
                            image_map {
                                png Forearm_L_IMap
                                map_type 2
                                interpolate 4
                                once
                            } 
                            rotate y*180
                            scale 15
                            translate <0,-12,0>
                        }
                        #ifdef (Map_Finish)
                            finish {Map_Finish}
                        #end
                        #ifdef (Map_Normal)
                            normal {Map_Normal}
                        #end
                        #ifdef (Forearm_L_BMap)
                            normal {
                                bump_map {
                                    png Forearm_L_BMap
                                    map_type 2 
                                    interpolate 4
                                    once
                                    bump_size Bump_Map_Size
                                }
                                rotate y*180
                                scale 15
                                translate <0,-15,0>
                            }
                        #end
                    }
                #end
            }
            transform L_Forearm
        }
// Legs
// Thigh - Right
        union {
            blob{
                threshold build-.3
                #if (BM_R_Thigh_Mass>= 2)
                    cylinder{<0,0,0>,<0,-ThighLength,0>,4,4}
                    sphere  {<0,0,0>5,4 scale <1,ThighLength*.15,1> translate <0,-ThighLength*.15-2,0>}
                    sphere  {<0,-1.5,.5>,5,-2.5 scale <1,4,1> translate y*-ThighLength} 
                    sphere  {<0,0,0>,4, 2.5 translate y*-(ThighLength+1.5) }
                #end
                #if (BM_R_Thigh_Mass = 1)
                    cylinder{<0,0,0>,<0,-ThighLength,0>,4,4}
                    sphere  {<0,-1.5,.5>,5,-2.5 scale <1,4,1> translate y*-ThighLength} 
                    sphere  {<0,0,0>,4, 2.5 translate y*-(ThighLength+1.5)}
                #end
                #if (BM_R_Thigh_Mass= 0)
                    sphere  {<0,0,0>.00001,0.00000001 pigment {rgbft 1}}
                #end
                #if (BM_R_Thigh_Mass< 0)
// Object Guides
                    cylinder{<0,0,0>,<0,-ThighLength,0>,Guide_Rad,2}
                #end
            }
            object {Thigh_R_Object}
            material {
                texture {Skin_Tex}
                #ifdef (Thigh_R_IMap)
                    texture {
                        pigment {
                            image_map {
                                png Thigh_R_IMap
                                map_type 2 
                                interpolate 4
                                once
                            }
                            rotate y*-90
                            scale 25
                            translate <0,-17.5,0>
                        }
                        #ifdef (Map_Finish)
                            finish {Map_Finish}
                        #end
                        #ifdef (Map_Normal)
                            normal {Map_Normal}
                        #end
                        #ifdef (Thigh_R_BMap)
                            normal {
                                bump_map {
                                    png Thigh_R_BMap
                                    map_type 2 
                                    interpolate 4
                                    once
                                    bump_size Bump_Map_Size
                                }
                                rotate y*-90
                                scale 25
                                translate <0,-17.5,0>
                            }
                        #end
                    }
                #end
            }
            transform R_Thigh
        }
// Thigh - Left
        union {
            blob {
                threshold build-.3
                #if (BM_L_Thigh_Mass>= 2)
                    cylinder{<0,0,0>,<0,-ThighLength,0>,4,4}
                    sphere  {<0,0,0>5,4 scale <1,ThighLength*.15,1> translate <0,-ThighLength*.15-2,0>}
                    sphere  {<0,-1.5,.5>,5,-2.5 scale <1,4,1> translate y*-ThighLength}
                    sphere  {<0,0,0>,4, 2.5 translate y*-(ThighLength+1.5)}                            
                #end
                #if (BM_L_Thigh_Mass = 1)
                    cylinder{<0,0,0>,<0,-ThighLength,0>,4,4}
                    sphere  {<0,-1.5,.5>,5,-2.5 scale <1,4,1> translate y*-ThighLength}
                    sphere  {<0,0,0>,4, 2.5 translate y*-(ThighLength+1.5)}
                #end
                #if (BM_L_Thigh_Mass= 0)
                    sphere  {<0,0,0>.00001,0.000000001 pigment {rgbft 1}}
                #end
                #if (BM_L_Thigh_Mass< 0)
// Object Guides
                    cylinder{<0,0,0>,<0,-ThighLength,0>,Guide_Rad,2}
                #end
            }
            object {Thigh_L_Object}
            material {
                texture {Skin_Tex}
                #ifdef (Thigh_L_IMap)
                    texture {
                        pigment {
                            image_map {
                                png Thigh_L_IMap
                                map_type 2 
                                interpolate 4
                                once
                            } 
                            rotate y*-90
                            scale 25
                            translate <0,-17.5,0>
                        }
                        #ifdef (Map_Finish)
                            finish {Map_Finish}
                        #end
                        #ifdef (Map_Normal)
                            normal {Map_Normal}
                        #end
                        #ifdef (Thigh_L_BMap)
                            normal {
                                bump_map {
                                    png Thigh_L_BMap
                                    map_type 2 
                                    interpolate 4
                                    once
                                    bump_size Bump_Map_Size
                                }
                                rotate y*-90
                                scale 25
                                translate <0,-17.5,0>
                            }
                        #end
                    }
                #end
            }
            transform L_Thigh
        }
// Calf - Right
        union {
            blob{
                threshold build-.3
                #if (BM_R_Calf_Mass>= 2)
                    cylinder{<0,0,0>,<0,-CalfLength,0>,3,2}
                    sphere  {<0,0,0>4,4 scale <1,CalfLength*.15,1.05> translate <0,-CalfLength*.15-3,0>}
                    sphere  {<0,0,0>,3,-1.25 scale <1,2,1> translate y*-CalfLength}
                #end
                #if (BM_R_Calf_Mass = 1)
                    cylinder{<0,0,0>,<0,-CalfLength,0>,3,2}
                    sphere  {<0,0,0>,3,-1.25 scale <1,2,1> translate y*-CalfLength}
                #end
                #if (BM_R_Calf_Mass= 0)
                    sphere  {<0,0,0>.00001,0.00000001 pigment {rgbft 1}}
                #end
                #if (BM_R_Calf_Mass< 0)
// Object Guides
                    cylinder{<0,0,0>,<0,-CalfLength,0>,Guide_Rad,2}
                #end
            }
            object {Calf_R_Object}
            material {
                texture {Skin_Tex}
                #ifdef (Calf_R_IMap)
                    texture {
                        pigment {
                            image_map {
                                png Calf_R_IMap
                                map_type 2
                                interpolate 4
                                once
                            } 
                            rotate y*-90
                            scale 25
                            translate <0,-20,0>
                        }
                        #ifdef (Map_Finish)
                            finish {Map_Finish}
                        #end
                        #ifdef (Map_Normal)
                            normal {Map_Normal}
                        #end
                        #ifdef (Calf_R_BMap)
                            normal {
                                bump_map {
                                    png Calf_R_BMap
                                    map_type 2
                                    interpolate 4
                                    once
                                    bump_size Bump_Map_Size
                                }
                                rotate y*-90
                                scale 25
                                translate <0,-20,0>
                            }
                        #end
                    }
                #end
            }
            transform R_Calf
        }
// Calf - Left
        union {
            blob {
                threshold build-.3
                #if (BM_L_Calf_Mass>= 2)
                    cylinder{<0,0,0>,<0,-CalfLength,0>,3,2}
                    sphere  {<0,0,0>4,4 scale <1,CalfLength*.15,1.05> translate <0,-CalfLength*.15-3,0>}
                    sphere  {<0,0,0>,3,-1.25 scale <1,2,1> translate y*-CalfLength}
                #end
                #if (BM_L_Calf_Mass = 1)
                    cylinder{<0,0,0>,<0,-CalfLength,0>,3,2}
                    sphere  {<0,0,0>,3,-1.25 scale <1,2,1> translate y*-CalfLength}
                #end
                #if (BM_L_Calf_Mass= 0)
                    sphere  {<0,0,0>.00001,0.0000001 pigment {rgbft 1}}
                #end
                #if (BM_L_Calf_Mass< 0)
// Object Guides
                    cylinder{<0,0,0>,<0,-CalfLength,0>,Guide_Rad,2}
                #end
            }
            object {Calf_L_Object}
            material {
                texture {Skin_Tex}
                #ifdef (Calf_L_IMap)
                    texture {
                        pigment {
                            image_map {
                                png Calf_L_IMap
                                map_type 2 
                                interpolate 4
                                once
                            } 
                            rotate y*-90
                            scale 25
                            translate <0,-20,0>
                        }
                        #ifdef (Map_Finish)
                            finish {Map_Finish}
                        #end
                        #ifdef (Map_Normal)
                            normal {Map_Normal}
                        #end
                        #ifdef (Calf_L_BMap)
                            normal {
                                bump_map {
                                    png Calf_L_BMap
                                    map_type 2 
                                    interpolate 4
                                    once
                                    bump_size Bump_Map_Size
                                }
                                rotate y*-90
                                scale 25
                                translate <0,-20,0>
                            }
                        #end
                    }
                #end
            }
            transform L_Calf
        }
    }
//Origin Variables
    #declare Origin_RL=< 4,31,0>-R_Ankle-R_Knee;
    #declare Origin_LL=<-4,31,0>-L_Ankle-L_Knee;
    #declare Origin_RA=< 9,20,0>-R_Elbow-R_Wrist;
    #declare Origin_LA=<-9,20,0>-L_Elbow-L_Wrist;
#end


/***************************************************************

Head Macro
- - - - - 
Usage :

head( build , eye , R_Lid, L_Lid , EyeRot , lip , skin , Twist , Tip , Tilt )

build     = Blob Threshold Level                                      - standard: .5
eye       = Iris Colour of eye (<r,g,b>) - i.e. <.75,1,1> = Pale Blue
R_Lid     = Right Eye Lid Position  (range : 0-Open to 1-Closed)      - standard: 0
L_Lid     = Left Eye Lid Position  (range : 0-Open to 1-Closed)       - standard: 0
EyeRot    = Eye Rotation Angle left-right                             - standard: 0
lip       = Mouth Size (range: -0.5 to 0.5 )                          - standard: 0
skin      = Skin color (<r,g,b>)                                      - standard: <.9,.7,.6>
Twist     = Head rotation Right to Left (range: -85 to 85)            - standard: 0
Tip       = Head position Front to Back (range: -15 to 50)            - standard: 0
Tilt      = Head position Right Side to Left Side  (range: -25 to 25) - standard: 0
Face_Map  = Image Map used for face 0= No Map 1-5 is number of png file.
            Name of file is bmface#.png where # is Face_Map Number, uses aplha channel.

*****************************************************************/

#macro head(build,eye,R_Lid,L_Lid,EyeRot,lip,Twist,Tip,Tilt,Face_Map)
    #ifndef (BM_Mouth)
        #local BM_Mouth=lip;
    #end
    #local MouthWidth=BM_Mouth+1.5;
    #local MouthHeight=BM_Jaw;
    union {
        blob {
            threshold build
            #if (BM_Head_Mass>= 1)
                sphere{0,5.6,2  } // Top of Skull
                sphere{0,4.2,2 scale<1,1.4,1> translate <0,-1.4,-.7>}  //Lower Jaw
                sphere{0,2.8,2 scale<1,1.4*(BM_Jaw*.25+1),1> rotate x*(BM_Jaw*25) translate <0,-2.8,-1.4> } // Chin
                sphere{0,1,1  scale <2,1,1> translate <0,-5.,-2.75> rotate x*(BM_Jaw*1.5)}   // Chin
// Brow Ridge
                #if (BM_Face>0)
                    #if (BM_Brow>0)
                        #local Loop=0;
                        #while (Loop<90)
                            sphere{<0,.8,-3.25>.009*(90-Loop),3.5 rotate y*Loop translate <0,-.009*(90-Loop)+.25,-.65>}
                            sphere{<0,.8,-3.25>.009*(90-Loop),3.5 rotate y*-Loop translate <0,-.009*(90-Loop)+.25,-.65>}
                            #local Loop=Loop+5;
                        #end
                    #end
// Nose
                    cylinder{<0,1,.5><0,-1,-BM_Nose>,1,2 translate <0,-.7,-3.5>}   // Nose
                    cylinder{<-.7,0,0><.7,0,0>,.5,2 translate<0,-1.75,-3.85>} // Nostrils
                #end
// Eye Ridge Socket
                #if (BM_Face>0)
                    sphere{0,2,-1.5 scale<1.5,.7,1.5> rotate x*-25 translate<0,-.65,-4> rotate y*35}
                    sphere{0,2,-1.5 scale<1.5,.7,1.5> rotate x*-25 translate<0,-.65,-4> rotate y*-35}
                    sphere{0,3,-1.5 scale<1.5,.7,1> translate<0,-1,-5> rotate y*35}
                    sphere{0,3,-1.5 scale<1.5,.7,1> translate<0,-1,-5> rotate y*-35}
                #else
                    sphere{0,2,-1 scale<1.5,.7,.75> translate<0,-1.6,-4> rotate y*40}
                    sphere{0,2,-1 scale<1.5,.7,.75> translate<0,-1.6,-4> rotate y*-40}
                #end
// Cheeks
                sphere{0,3,-1.75 scale <1,1,1> translate <-2.75,-2.5,-3.5>}
                sphere{0,3,-1.75 scale <1,1,1> translate <2.75,-2.5,-3.5>}
                sphere{0,1.5,BM_Jowls+.0000001 scale <1,1.5,1> translate <0,-2.5,-2.5> rotate y*-55}
                sphere{0,1.5,BM_Jowls+.0000001 scale <1,1.5,1> translate <0,-2.5,-2.5> rotate y* 55}            
// Ears
                #if (BM_Ears>= 2)
                    sphere{0,1,2 scale<1,1.75,.7> rotate y*45 rotate z*15 translate<-4.2,-.85,0> } // Outer Ear Right
                    sphere{0,1,-2 scale<1,1.75,.7>*.7 rotate y*45 rotate z*15 translate<-4.2,-.7,-.35>} // Inner Ear Right
                    sphere{0,1,2 scale<1,1.75,.7>/3.5 rotate y*45 rotate z*15 translate<-4.025,-.7,-.35> } // Inner Ear Canal Right
                    sphere{0,1,2 scale<1,1.75,.7> rotate y*-45 rotate z*-15 translate<4.2,-.85,0> } // Outer Ear Left
                    sphere{0,1,-2 scale<1,1.75,.7>*.7 rotate y*-45 rotate z*-15 translate<4.2,-.7,-.35>} // Inner Ear Left
                    sphere{0,1,2 scale<1,1.75,.7>/3.5 rotate y*-45 rotate z*-15 translate<4.025,-.7,-.35>} // Inner Ear Canal Left
                #end
                #if (BM_Ears = 1)
                    sphere{0,1,2 scale<1,1,1> scale <1,1.75,1.5> rotate z*5 translate<-3.5,-.85,0> } // Outer Ear Right
                    sphere{0,1,2 scale<1,1,1> scale <1,1.75,1.5> rotate z*-5 translate<3.5,-.85,0> } // Outer Ear Left
                #end
// Mouth
                #if (BM_Face>0)
                    #if (BM_Jaw>1)              
                        #local MouthHeight=1;
                    #end
                    #if (MouthHeight<=.25)
                        #local MouthHeight=.5;
                    #end
// Inside of Mouth
                    sphere {0,1,-2 scale <MouthWidth*.75,MouthHeight,1.5> translate <0,-3.5,-2.25> pigment {rgb -1.5}}
// Lips
                    sphere {0,1.25,1 translate x*.5 scale <MouthWidth*.5,MouthHeight,2> rotate y*-7 translate <0,-3.5,-3.05+.5> texture {Lip_Tex}}
                    sphere {0,1.25,.75 scale <MouthWidth*.5,MouthHeight,2> translate <0,-3.5,-3.05+.5> texture {Lip_Tex}}
                    sphere {0,1.25,1 translate x*-.5 scale <MouthWidth*.5,MouthHeight,2> rotate y*7 translate <0,-3.5,-3.05+.5> texture {Lip_Tex}}
// Create Opening
                    sphere {0,1,-2.75 scale <MouthWidth*.9,MouthHeight-.15,2> translate <0,-3.5,-3.05+.25> texture {Lip_Tex}}
                #end
// Eyes Sockets
            #end
            #if (BM_Head_Mass= 0)
                sphere  {<0,0,0>.00001,0.0000001 pigment {rgbft 1}}
            #end
            #if (BM_Head_Mass< 0)
// Object Guides
                sphere{0,5.6,2 } // Top of Skull
                sphere{0,4.2,2 scale<1,1.4,1> translate <0,-1.4,-.7> } //Lower Jaw
                sphere{0,2.8,2 scale<1,1.4,1> translate <0,-2.8,-1.4>} // Chin
            #end
        }
// Teeth
        #if (BM_Teeth)
            #if (MouthHeight>.5)
                difference {
                    union {
                        cylinder {<0,-.075,.05><0,.5,0> 1 scale <1.5*.75,1,2.5> rotate x*(BM_Jaw*5) translate <0,-3.45,-1.25>}
                        cylinder {<0,-.05,0><0,-.25,0> 1 scale <1.5*.75,1,2.5> rotate x*-(BM_Jaw*5) translate <0,-3.5,-1.25>}
                    }
                    union {
                        cylinder {<0,-.0750001,.05><0,.50001,0> .9 scale <1.5*.75,1,2.5> rotate x*(BM_Jaw*5) translate <0,-3.45,-1.25>}
                        cylinder {<0,0,0><0,-.5001,0> .9 scale <1.5*.75,1,2.5> rotate x*-(BM_Jaw*5) translate <0,-3.5,-1.25>}
                    }
                    texture {
                        pigment {Tooth_Pig}
                        normal {quilted 1 scale <.5,5,1>}
                        finish {phong .9 phong_size 90}
                    }
                }
            #end
        #end    
// Eyes
        #if (BM_Eyes>0)
            union {
                sphere{0,1 pigment{rgb 1}}
                sphere{0,.7 translate z*-.35 rotate y*18 pigment{rgb eye}}
                sphere{0,.2 translate z*-.9  rotate y*18 pigment{rgb 0}}
                difference {
                    sphere{0,1.1 }
                    box {<5,5,0><-5,-5,-10> }
                    rotate y*9
                    rotate x*-(L_Lid*65+65)
                }
                rotate x*-7
                rotate y*-15
                rotate <0,EyeRot+20,0>
                #if (BM_Face>0)
                    translate<0,-.35,-2.5>
                #else
                    translate<0,-.35,-2.8>
                #end
                rotate y*-40
            }
            union {
                sphere{0,1 pigment{rgb 1}}
                sphere{0,.7 translate z*-.35 rotate y*-18 pigment{rgb eye}}
                sphere{0,.2 translate z*-.9  rotate y*-18 pigment{rgb 0}} 
                difference {
                    sphere{0,1.1 }
                    box {<2,2,0><-2,-2,-4> }
                    rotate y*-9
                    rotate x*-(R_Lid*65+65)
                }
                rotate x*-7
                rotate y*15
                rotate <0,EyeRot-20,0>
                #if (BM_Face>0)
                    translate<0,-.35,-2.5>
                #else
                    translate<0,-.35,-2.8>
                #end
                rotate y*40 
            }
        #else
            object {nul}
        #end
        object {Head_Object}
        material {
            texture {Skin_Tex}
            #ifndef (Face_IMap)
                #local Face_IMap=concat ("bmface", str(Face_Map,0,0),".png")
            #else
                #local Face_Map=1;
            #end
            #if (Face_Map>0)
                texture {
                    pigment {
                        image_map {
                            png Face_IMap
                            map_type 2 
                            interpolate 4
                            once
                        } 
                        rotate y*-90
                        translate <0,-.55,0>
                        scale 12
                    }
                    #ifdef (Map_Finish)
                        finish {Map_Finish}
                    #end             
                    #ifdef (Map_Normal)
                        normal {Map_Normal}
                    #end
                    #ifdef (Face_BMap)
                        normal {
                            bump_map {
                                png Face_BMap
                                map_type 2
                                interpolate 4
                                once
                                bump_size Bump_Map_Size
                            } 
                            rotate y*-90
                            translate <0,-.55,0>
                            scale 12
                        }
                    #end
                }
            #end
        }
// Head Tilt, Tip & Twist
        scale 1.1
        translate <0,5,-1>
        rotate z*Tilt
        rotate x*Tip
        rotate y*Twist
        translate <0,-5,1>
    }
#end

/****************************************************************

Hand Macro
- - - - - 
Usage: Call this macro twice, once for each hand.

hand( build , skin , H_S2E , H_E2W , H_Rot , Hand, F_Spread, FP_Pos, FR_Pos, FM_Pos, FI_Pos, FT_Pos )

build    =  Blob Threshold Level                  - standard: 0.5
skin     =  Skin color (<r,g,b>)                  - standard: <.9,.7,.6>
H_S2E    =* Arm Shoulder to Elbow rotation vector - standard: Same as Torso
H_E2W    =* Arm Elbow to Wrist rotation vector    - standard: Same as Torso
H_Rot    =  Hand rotation Vector                  - standard: <0,0,0>
Hand     =  Right Hand = -1 / Left Hand = 1
F_Spread =  Finger Spread    - 0 = Closed   , 1 = Relaxed , 2 = Wide
FP_Pos   =  Pinky Position   - 0 = Straight , 1 = Relaxed , 2 = Curled
FR_Pos   =  Ring Position    - 0 = Straight , 1 = Relaxed , 2 = Curled
FM_Pos   =  Middle Position  - 0 = Straight , 1 = Relaxed , 2 = Curled
FI_Pos   =  Index Position   - 0 = Straight , 1 = Relaxed , 2 = Curled
FT_Pos   =  Thumb Position   - 0 = Straight , 1 = Relaxed , 2 = Curled

* These MUST be the same as the Torso Macro if they are to line up correctly.

*******************************************************************/

#macro hand(build,H_S2E,H_E2W,H_Rot,Hand,F_Spread,FP_Pos,FR_Pos,FM_Pos,FI_Pos,FT_Pos)

    #local UpperarmLength=11;
    #local ForearmLength = 9;

    #local H_Elbow=vrotate(<0,-UpperarmLength,0>,H_S2E);
    #local H_Wrist=vrotate(<0,-ForearmLength,0> ,H_E2W);

//Finger Curl Angles
    #if (FP_Pos=1) #local FPA=8;   #else   #local FPA=20*FP_Pos;  #end
    #if (FR_Pos=1) #local FRA=8;   #else   #local FRA=20*FR_Pos;  #end
    #if (FM_Pos=1) #local FMA=8;   #else   #local FMA=20*FM_Pos;  #end
    #if (FI_Pos=1) #local FIA=8;   #else   #local FIA=20*FI_Pos;  #end
    #if (FT_Pos=1) #local FTA=15;  #else   #local FTA=7.5*FT_Pos; #end
//Finger Rotations
    #local FP_Rot=<FP_Pos*-FPA , 0 , 4*F_Spread*2>;
    #local FR_Rot=<FR_Pos*-FRA , 0 , 4*F_Spread  >;
    #local FM_Rot=<FM_Pos*-FMA , 0 , 0           >;
    #local FI_Rot=<FI_Pos*-FIA , 0 ,-4*F_Spread  >;
    #local FT_Rot=< 0 , 20*FT_Pos , FT_Pos*FTA >;
// Finger Section Lengths
    #local FP_L=2.12;  //Lower Pinky
    #local FP_U=1.54;  //Upper Pinky
    #local FR_L=2.76;  //Lower Ring
    #local FR_U=1.72;  //Upper Ring
    #local FM_L=2.92;  //Lower Middle
    #local FM_U=1.75;  //Upper Middle
    #local FI_L=3.01;  //Lower Index
    #local FI_U=1.28;  //Upper Index
    #local FT_L=1.01;  //Lower Thumb
    #local FT_U=1.50;  //Upper Thumb

// Finger Transformations
    #local FPL_Tran=transform {rotate FP_Rot translate < -1.97 , 3.94 , 1.25 > }
    #local FPU_Tran=transform {rotate FP_Rot+FP_Rot+<-10,0,0> translate vrotate(<0,FP_L,0>,FP_Rot) translate < -1.97 , 3.94 , 1.25 >}
    #local FRL_Tran=transform {rotate FR_Rot translate < -0.65 , 3.94 , 1.75 > }
    #local FRU_Tran=transform {rotate FR_Rot+FR_Rot+<-10,0,0> translate vrotate(<0,FR_L,0>,FR_Rot) translate < -0.65 , 3.94 , 1.75 >}
    #local FML_Tran=transform {rotate FM_Rot translate <  0.69 , 3.94 , 1.75 > }
    #local FMU_Tran=transform {rotate FM_Rot+FM_Rot+<-10,0,0> translate vrotate(<0,FM_L,0>,FM_Rot) translate <  0.69 , 3.94 , 1.75 >}
    #local FIL_Tran=transform {rotate FI_Rot translate <  2.02 , 3.48 , 1.25 > }
    #local FIU_Tran=transform {rotate FI_Rot+FI_Rot+<-10,0,0> translate vrotate(<0,FI_L,0>,FI_Rot) translate <  2.02 , 3.48 , 1.25 >}
    #local FTL_Tran=transform {rotate FT_Rot translate < 2.0 , 1.5 ,-.0 >}
    #local FTU_Tran=transform {rotate FT_Rot+FT_Rot translate < 2.0+FT_L , 1.5+FT_L ,-0.25 >}

    #local Hand_Trans=transform {rotate y*(90*Hand) rotate H_Rot rotate H_E2W translate H_Elbow+H_Wrist+<9*Hand,-UpperarmLength,.5>}
    #if (Hand=-1)
        #local TempHand=BM_R_Hand;
    #else
        #local TempHand=BM_L_Hand;
    #end
    union {
        blob {
            threshold build
            #if (TempHand>=1)
                sphere { 0, 1.65, .75 scale <1.85,1.05,.75> rotate y*-25 translate <-1.15,3.8,1.25> } //palm
                sphere { 0, 1.65, .75 scale <1.85,1.075,.75> rotate y*25 translate <1.15,3.8,1.25> }  //palm
                sphere { 0, 1.70, .75 scale <1.78, 1.3,.75> rotate y*-25 translate <-1,2.6,1> }       //midhand
                sphere { 0, 1.70, .75 scale <1.78, 1.3,.75>  rotate y*25 translate <0.69,2.6,1> }     //midhand
                sphere { 0, 1.7, .85 scale <1.4, 1.25,.75> rotate y*-25 translate <-0.55,1.2,0.5> }   //heel
                sphere { 0, 1.7, .85 scale <1.4, 1.25,.75> rotate y*25 translate <0.54,1.2,0.5>}      //heel
                sphere { 0, 1.7, .85 scale <1.3,1,1> translate <0.35,0.5,0.5>}                        //wrist
                sphere { 0, 1.7, -.75 scale <3,3,1> translate <0,2,2.85>}     // counteract bulge on back of hand

                cylinder { <0,0,0><0,FP_L,0>1,1 transform FPL_Tran }          //lower pinky
                cylinder { <0,0,0><0,FP_U,0>1,1 transform FPU_Tran }          //upper pinky
                sphere { 0, 1, -1 transform FPL_Tran }                        //counteract pinky palm bulge
                sphere { 0, 1, -1 transform FPU_Tran }                        //counteract pinky knuckle bulge
                cylinder { <0,0,0><0,FR_L,0>1,1 transform FRL_Tran }          //lower ring
                cylinder { <0,0,0><0,FR_U,0>1,1 transform FRU_Tran }          //upper ring    
                sphere { 0, 1, -1 transform FRL_Tran }                        //counteract ring palm bulge
                sphere { 0, 1, -1 transform FRU_Tran }                        //counteract ring knuckle bulge
                cylinder { <0,0,0><0,FM_L,0>1,1 transform FML_Tran }          //lower middle
                cylinder { <0,0,0><0,FM_U,0>1,1 transform FMU_Tran }          //upper middle
                sphere { 0, 1, -1 transform FML_Tran }                        //counteract middle palm bulge
                sphere { 0, 1, -1 transform FMU_Tran }                        //counteract middle knuckle bulge
                cylinder { <0,0,0><0,FI_L,0>1,1 transform FIL_Tran }          //lower index
                cylinder { <0,0,0><0,FI_U,0>1,1 transform FIU_Tran }          //upper index
                sphere { 0, 1, -1 transform FIL_Tran }                        //counteract index palm bulge
                sphere { 0, 1, -1 transform FIU_Tran }                        //counteract index knuckle bulge
                cylinder { <0,0,0><FT_L,FT_L,-.25>1.25,1 transform FTL_Tran } //lower thumb
                cylinder { <0,0,0><FT_U,FT_U,-.25>1.25,1 transform FTU_Tran } //upper thumb
                sphere { 0, 1.25, -.5 transform FTL_Tran }                    //counteract thumb palm bulge
                sphere { 0, 1.25, -1 transform FTU_Tran }                     //counteract thumb knuckle bulge
            #end
            #if (TempHand=0)
                sphere {<0,0,0>.00001,0.0000001 pigment {rgbft 1}}
            #end
            translate <0,0,-0.5>
            scale <Hand,-1,1>
            scale .85
        }
        #if (Hand=-1)
// Right Hand Object
            object {Hand_R_Object rotate y*(-90*Hand)}
        #else
// Left Hand Object
            object {Hand_L_Object rotate y*(-90*Hand)}
        #end
        #if (Hand=-1)
            material {
                texture {Skin_Tex}
                #ifdef (Hand_R_IMap)
                    texture {
                        pigment {
                            image_map {
                                png Hand_R_IMap
                                map_type 2 
                                interpolate 4
                                once
                            }
                            rotate y*90
                            scale 8.5
                            translate <0,-8,0>
                        }
                        #ifdef (Map_Finish)
                            finish {Map_Finish}
                        #end
                        #ifdef (Map_Normal)
                            normal {Map_Normal}
                        #end
                        #ifdef (Hand_R_BMap)
                            normal {
                                bump_map {
                                    png Hand_R_BMap
                                    map_type 2
                                    interpolate 4
                                    once
                                    bump_size Bump_Map_Size
                                }
                                rotate y*90
                                scale 8.5
                                translate <0,-8,0>
                            }
                        #end
                    }
                #end
            }
        #else
            material {
                texture {Skin_Tex}
                #ifdef (Hand_L_IMap)
                    texture {
                        pigment {
                            image_map {
                                png Hand_L_IMap
                                map_type 2 
                                interpolate 4
                                once
                            } 
                            rotate y*-90
                            scale 8.5
                            translate <0,-8,0>
                        }
                        #ifdef (Map_Finish)
                            finish {Map_Finish}
                        #end
                        #ifdef (Map_Normal)
                            normal {Map_Normal}
                        #end
                        #ifdef (Hand_L_BMap)
                            normal {
                                bump_map {
                                    png Hand_L_BMap
                                    map_type 2 
                                    interpolate 4
                                    once
                                    bump_size Bump_Map_Size
                                }
                                rotate y*-90
                                scale 8.5
                                translate <0,-8,0>
                            }
                        #end
                    }
                #end
            }
        #end
        #ifdef (BM_Hand_Scale)
            scale BM_Hand_Scale
        #end
        transform Hand_Trans
    }
#end


/****************************************************************

Feet Macro
- - - - -
Usage:

feet( build , skin , RF_H2K , RF_K2A , LF_H2K , LF_K2A , RF_Rot , LF_Rot)

build  =  Blob Threshold Level                        - standard: 0.5
skin   =  Skin color (<r,g,b>)                        - standard: <.9,.7,.6>
RF_H2K =* Right Leg Hip to Knee rotation vector       - standard: As Torso
RF_K2A =* Right Leg Knee to Ankle rotation vector     - standard: As Torso
LF_H2K =* Right Leg Hip to Knee rotation vector       - standard: As Torso
LF_K2A =* Right Leg Knee to Ankle rotation vector     - standard: As Torso
RF_Rot =  Right Foot rotation Vector                  - standard: <0,0,0>
LF_Rot =  Left Foot rotation Vector                   - standard: <0,0,0>

* These MUST be the same as the Torso Macro if they are to line up correctly.  

******************************************************************/

#macro feet(build,RF_H2K,RF_K2A,LF_H2K,LF_K2A,RF_Rot,LF_Rot)

    #local ThighLength=14;
    #local CalfLength =17;

    #local RF_Knee =vrotate(<0,-ThighLength,0>,RF_H2K);
    #local RF_Ankle=vrotate(<0,-CalfLength,0> ,RF_K2A);
    #local LF_Knee =vrotate(<0,-ThighLength,0>,LF_H2K);
    #local LF_Ankle=vrotate(<0,-CalfLength,0> ,LF_K2A);

    #local R_Foot_Trans=transform {rotate RF_Rot rotate RF_K2A translate RF_Knee+RF_Ankle+<-4,-29,0>}
    #local L_Foot_Trans=transform {rotate LF_Rot rotate LF_K2A translate LF_Knee+LF_Ankle+< 4,-29,0>}
    #declare Figure_Rotate_RF = -RF_Rot;
    #declare Figure_Rotate_LF = -LF_Rot;
    
    union {
 // Right Foot
        union {
            blob {
                threshold build-0.3
                #if (BM_R_Foot>=1)
                    sphere {<0,-1,.5>,3,2}
                    sphere {0,3,2 scale <1.5,.5,.75> rotate y*-15 translate <0,-2,-8> }
                    cylinder {<0, 3,0><0,-2.5,-6>3,3 scale <1,.5,1> } 
                    cylinder {<0,1.5,0><0,-2.5,-7>3,2 rotate y*-10 scale <1,.5,1>}
                    cylinder {<0,1.5,0><0,-2.5,-7>3,2 rotate y*  8 scale <1,.5,1>}
                    cylinder {<0,-2.5,0><0,-2.5,-6>3,2 scale <1,.65,1>} 
                    cylinder {<0,-2.5,0><0,-2.5,-7>3,2 rotate y*-10 scale <1,.65,1>}
                    cylinder {<0,-2.5,0><0,-2.5,-7>3,2 rotate y*  8 scale <1,.65,1>}
                    #if (BM_Toes>0)
                        sphere {0,1.5,2 scale <1,1,1.25> rotate x *-15 translate <-2.5,-2,-10>}
                        sphere {0,1.1,2 scale <1,1,1.25> rotate x *-15 translate <-1.0,-2,-10>}
                        sphere {0,1.0,2 scale <1,1,1.25> rotate x *-15 translate < 0.5,-2,-9.75>}
                        sphere {0,0.9,2 scale <1,1,1.25> rotate x *-15 translate < 2,-2,-9.25>}
                        sphere {0,0.8,2 scale <1,1,1.25> rotate x *-15 translate < 3.25,-2,-8.5>}
                    #else
                       sphere {0,3,2 scale <1.5,.5,.75> rotate y*-15 translate <0,-2,-10>}
                        sphere {0,3,2 scale <1.5,.5,1> rotate y*-15 translate <0,-1.5,-9>}
                    #end
                    cylinder {<0,-5,0><0,5,0>5,-3 translate <-4,0,-5>}
                    cylinder {<0,-5,0><0,5,0>3,-2.5 scale <1,1,1.5> rotate z*-15 translate < 4,0,-4>}
                #end
                #if (BM_R_Foot=0)
                    sphere {<0,0,0>.00001,0.00001 pigment {rgbft 1}}
                #end
                scale <-.75,.75,.75>
                translate y*-1
            }
            object {Foot_R_Object}
            material {
                texture {Skin_Tex}
                #ifdef (Foot_R_IMap)
                    texture {
                        pigment {
                            image_map {
                                png Foot_R_IMap
                                map_type 0 
                                interpolate 4
                                once
                            } 
                            scale 8
                            translate <-4,-4,-4>
                        }
                        #ifdef (Map_Finish)
                            finish {Map_Finish}
                        #end
                        #ifdef (Map_Normal)
                            normal {Map_Normal}
                        #end
                        #ifdef (Foot_R_BMap)
                            normal {
                                bump_map {
                                    png Foot_R_BMap
                                    map_type 2 
                                    interpolate 4
                                    once
                                    bump_size Bump_Map_Size
                                }
                                scale 8
                                translate <-4,-4,-4>
                            }
                        #end
                    }
                #end
            }
            transform R_Foot_Trans
        }
// Left Foot
        union {
            blob {
                threshold build-0.3
                #if (BM_L_Foot>=1)
                    sphere {<0,-1,.5>,3,2}
                    sphere {0,3,2 scale <1.5,.5,.75> rotate y*-15 translate <0,-2,-8>}
                    cylinder {<0, 3,0><0,-2.5,-6>3,3 scale <1,.5,1>} 
                    cylinder {<0,1.5,0><0,-2.5,-7>3,2 rotate y*-10 scale <1,.5,1>}
                    cylinder {<0,1.5,0><0,-2.5,-7>3,2 rotate y*  8 scale <1,.5,1>}
                    cylinder {<0,-2.5,0><0,-2.5,-6>3,2 scale <1,.65,1>} 
                    cylinder {<0,-2.5,0><0,-2.5,-7>3,2 rotate y*-10 scale <1,.65,1>}
                    cylinder {<0,-2.5,0><0,-2.5,-7>3,2 rotate y*  8 scale <1,.65,1>}
                    #if (BM_Toes>0)
                        sphere {0,1.5,2 scale <1,1,1.25> rotate x *-15 translate <-2.5,-2,-10>}
                        sphere {0,1.1,2 scale <1,1,1.25> rotate x *-15 translate <-1.0,-2,-10>}
                        sphere {0,1.0,2 scale <1,1,1.25> rotate x *-15 translate < 0.5,-2,-9.75>}
                        sphere {0,0.9,2 scale <1,1,1.25> rotate x *-15 translate < 2,-2,-9.25>}
                        sphere {0,0.8,2 scale <1,1,1.25> rotate x *-15 translate < 3.25,-2,-8.5>}
                    #else
                        sphere {0,3,2 scale <1.5,.5,.75> rotate y*-15 translate <0,-2,-10>}
                        sphere {0,3,2 scale <1.5,.5,1> rotate y*-15 translate <0,-1.5,-9>}
                    #end
                    cylinder {<0,-5,0><0,5,0>5,-3 translate <-4,0,-5>}
                    cylinder {<0,-5,0><0,5,0>3,-2.5 scale <1,1,1.5> rotate z*-15 translate < 4,0,-4>}
                #end
                #if (BM_L_Foot=0)
                    sphere  {<0,0,0>.00001,0.00001 pigment {rgbft 1}}
                #end
                scale .75
                translate y*-1
            }
            object {Foot_L_Object}
            material {
                texture {Skin_Tex}
                #ifdef (Foot_L_IMap)
                    texture {
                        pigment {
                            image_map {
                                png Foot_L_IMap
                                map_type 0
                                interpolate 4
                                once
                            } 
                            scale 8
                            translate <-4,-4,-4>
                        }
                        #ifdef (Map_Finish)
                            finish {Map_Finish}
                        #end
                        #ifdef (Map_Normal)
                            normal {Map_Normal}
                        #end
                        #ifdef (Foot_L_BMap)
                            normal {
                                bump_map {
                                    png Foot_L_BMap
                                    map_type 2
                                    interpolate 4
                                    once
                                    bump_size Bump_Map_Size
                                }
                                scale 8
                                translate <-4,-4,-4>
                            }
                        #end
                    }
                #end
            }
            transform L_Foot_Trans
        }
    }
#end

/****************************************************************

Hair Macro
- - - - -
Usage:

hair( Hair_On, Hair_Rot, Hair_Col, Hair_Arch, Hair_Thck, Hair_Line, Hair_LDpth, Hair_Wght, Hair_Hght, Hair_Length, 
      Hair_Curl, Twist, Tip, Tilt )

Hair_On        = Hair (1) or No Hair (0)
Hair_Rot       = Rotation Vector for Hair (<x,y,z>)            - standard: <0,0,0>
Hair_Col       = Hair Colour (<r,g,b>)
Hair_Arch      = Arch hairline over head inline with ears (1) or Not (0)
Hair_Thck      = Thickness of Hair (Best settings 0.15 to 0.5) - standard: 0.25
Hair_Line      = Height of Hairline (Best settings 3 to 6)     - standard: 5
Hair_LDpth     = Hairline profile Depth (Range: 0 to 1)        - standard: 0.7
Hair_Wght      = Hair Weight (Range 0.005 to 0.05)             - standard: 0.01
Hair_Hght      = Hair Height (Range 1 to 2)                    - Standard: 1
Hair_Length    = Hair Length (Range 1 to 20)                   - standard: 10
Hair_Curl      = Curliness (Range 0-Straight to 0.1-Curly)     - Standard: 0.05
Twist          =* Head Twist Angle                             - Standard: Same as Head
Tip            =* Head Tip Angle                               - Standard: Same as Head  
Tilt           =* Head Tilt Angle                              - Standard: Same as Head  

* These MUST be the same as the Head Macro if it is to line up correctly.  

*******************************************************************/

#macro hair(Hair_On,Hair_Rot,Hair_Col,Hair_Arch,Hair_Thck,Hair_Line,Hair_LDpth,Hair_Wght,Hair_Hght,Hair_Length,Hair_Curl,Twist,Tip,Tilt)
    #if (Hair_On=1)
        union{
            #ifdef (Hair_Seed)
                #local rr=seed(Hair_Seed);
            #else
                #local rr=seed(77);
            #end
            #local tt=0;
            #while (tt<20)
                #local zz=tt*3+3;
                #local cc=0;
                #while (cc<zz)
                    #local yy=cc*360/zz+rand(rr)*6;
                    #local xx=Hair_Line-sin((yy+15)*pi/30)*Hair_LDpth;
                    #local hh=vrotate(<0,.8,0>,<tt*xx+rand(rr)*5,yy,45>);
                    #local hx=hh.x;
                    #local hy=hh.y;
                    #local hz=hh.z;
                    #local dx=hx/50;
                    #local dy=hy/50*Hair_Hght;
                    #local dz=hz/50;
                    #if (Hair_Arch=1 & dx>0)
                    #local dy=dy+dx;
                    #local dx=-dx;
                #end
                #if (hy>-.25)
                    blob{
                        threshold .5
                        #local ll=0;
                        #local length=Hair_Length-rand(rr)*Hair_Length/5;
                        #local vv=rand(rr)*length;
                        #while (ll<length) 
                            sphere{<hx+Hair_Curl*sin((vv+ll)*pi/3),hy,hz+Hair_Curl*cos((vv+ll)*pi/3)>,Hair_Thck/5,1}
                            #local ll=ll+Hair_Thck;
                            #local hx=hx+dx;
                            #local hy=hy+dy;
                            #local hz=hz+dz;
                            #local dx=dx*(1-Hair_Wght*2);
                            #local dy=dy*(1-Hair_Wght/2)-Hair_Wght/20;
                            #local dz=dz*(1-Hair_Wght);
                            #if (Hair_Arch=1 & dx>0)
                                #local dy=dy+0.001;
                                #if (hx>-.5)
                                    #local hx=hx+dx;
                                #end
                            #end
                        #end
                        #ifndef (Hair_Tex)
                            pigment{rgb Hair_Col+<rand(rr)/10,rand(rr)/10,rand(rr)/10>}}
                        #else
                            texture {Hair_Tex}
                        #end
                    #end
                    #local cc=cc+1;
                #end
                #local tt=tt+1;
            #end
            rotate y*90
            rotate Hair_Rot
            scale 4.5
            translate <0,5,-1>
            rotate z*Tilt
            rotate x*Tip
            rotate y*Twist 
            translate <0,-5,1>
        }
    #else
        object {nul}
    #end
#end

// Debuging Device

#ifndef (DeBug)
    #declare DeBug=off;
#end

#declare Vector_Locator=
    union {
        cylinder {<-8,0,0><8,0,0> .5 pigment {rgb <1,0,0>}}
        cylinder {<0,0,-8><0,0,8> .5 pigment {rgb <0,1,0>}}
        cylinder {<0,-8,0><0,8,0> .5 pigment {rgb <0,0,1>}}
        torus {5,.4 pigment {rgb <1,1,0>}}
    }

// Default Settings for Optional Switches
#ifndef (Guide_Rad)
    #declare Guide_Rad=2;
#end
#ifndef (Hair_Seed)
    #declare Hair_Seed=77;
#end
#ifndef (BM_Ears) // 2 = Normal Ears, 1=Replace ears with small lumps as if under a swimming cap, 0 = No ears
    #declare BM_Ears=2;
#end
#ifndef (BM_Jaw)  // Range: 0=Closed, 1=Open
    #declare BM_Jaw=.5;
#end
#ifndef (BM_Teeth) // 0=No Teeth, 1=Teeth
    #declare BM_Teeth=1;
#end    
#ifndef (BM_Jowls) // Range 0 - 3 = Jowl Mass added to side of jaw. 
    #declare BM_Jowls=0;
#end    
#ifndef (BM_Toes) // 1 = Bare Foot with toes, 0 = Replaces toes so that foot looks like it has a sock on
    #declare BM_Toes=1;
#end               
#ifndef (BM_BodyStyle) // 0= Original Chest Modelling, 1=New Chest Modelling
    #declare BM_BodyStyle=0;
#end
#ifndef (BM_Nose) // Range 0 - 1.25 : Size of Nose
    #declare BM_Nose=.5;
#end               
#ifndef (BM_Face) // 1 = Normal Face Structure, 0 = Removes Nose and Lips
    #declare BM_Face=1;
#end         
#ifndef (BM_Brow) // Brow Ridge above eyes 1=On, 0=Off
    #declare BM_Brow=1;
#end
#ifndef (BM_R_Foot) // Right Foot 1 = Normal, 0 = Missing
    #declare BM_R_Foot=1;
#end
#ifndef (BM_L_Foot) // Left Foot 1 = Normal, 0 = Missing
    #declare BM_L_Foot=1;
#end
#ifndef (BM_R_Hand) // Right Hand 1 = Normal, 0 = Missing
    #declare BM_R_Hand=1;
#end
#ifndef (BM_L_Hand) // Left Hand 1 = Normal, 0 = Missing
    #declare BM_L_Hand=1;
#end
#ifndef (BM_Eyes) // Eyes 1=Normal 0=No Eyes
    #declare BM_Eyes=1;
#end
#ifndef (BM_R_Upperarm_Mass) // 2 = Muscles, 1 = Cylinders, 0 = Amputated, -1 = Guides
    #declare BM_R_Upperarm_Mass=2;
#end
#ifndef (BM_L_Upperarm_Mass) // 2 = Muscles, 1 = Cylinders, 0 = Amputated, -1 = Guides
    #declare BM_L_Upperarm_Mass=2;
#end
#ifndef (BM_R_Forearm_Mass) // 2 = Muscles, 1 = Cylinders, 0 = Amputated, -1 = Guides
    #declare BM_R_Forearm_Mass=2;
#end
#ifndef (BM_L_Forearm_Mass) // 2 = Muscles, 1 = Cylinders, 0 = Amputated, -1 = Guides
    #declare BM_L_Forearm_Mass=2;
#end
#ifndef (BM_R_Thigh_Mass) // 2 = Muscles, 1 = Cylinders, 0 = Amputated, -1 = Guides
    #declare BM_R_Thigh_Mass=2;
#end
#ifndef (BM_L_Thigh_Mass) // 2 = Muscles, 1 = Cylinders, 0 = Amputated, -1 = Guides
    #declare BM_L_Thigh_Mass=2;
#end
#ifndef (BM_R_Calf_Mass) // 2 = Muscles, 1 = Cylinders, 0 = Amputated, -1 = Guides
    #declare BM_R_Calf_Mass=2;
#end
#ifndef (BM_L_Calf_Mass) // 2 = Muscles, 1 = Cylinders, 0 = Amputated, -1 = Guides
    #declare BM_L_Calf_Mass=2;
#end
#ifndef (BM_Torso_Mass) // 1 = Normal Torso, 0 = No Torso, -1 = Guides
    #declare BM_Torso_Mass=1;
#end
#ifndef (BM_Head_Mass) // 1 = Normal Head, 0 = No Head, -1 = Guides
    #declare BM_Head_Mass=1;
#end
#ifndef (Bump_Map_Size)
    #declare Bump_Map_Size=0.25;
#end
// Define Default Textures
#ifndef (Skin_Tex)
    #declare Skin_Tex=
        texture {
            pigment{rgb <.9,.7,.6>}
            finish{
                phong .3 
                phong_size 40
            }
            normal{
                crackle .2 
                turbulence .7 
                scale .7
            }
        }
#end

#ifndef (Lip_Tex)
    #declare Lip_Tex =
        texture {
            pigment{rgb <.7,.3,.2>}
            finish{
                phong .3 
                phong_size 40
            }
            normal{
                crackle .2 
                turbulence .7 
                scale .7
            }
        }
#end

#ifndef (Tooth_Pig)
    #declare Tooth_Pig = pigment {rgb 1}
#end    

#declare nul=sphere{0,.0000001 pigment {rgbft 1}}
// Declare Default nul Objects
#ifndef (Head_Object)
    #declare Head_Object=object{nul}
#end
#ifndef (Torso_Object)
    #declare Torso_Object=object{nul}
#end
#ifndef (Upperarm_R_Object)
    #declare Upperarm_R_Object=object{nul}
#end
#ifndef (Upperarm_L_Object)
    #declare Upperarm_L_Object=object{nul}
#end
#ifndef (Forearm_R_Object)
    #declare Forearm_R_Object=object{nul}
#end
#ifndef (Forearm_L_Object)
    #declare Forearm_L_Object=object{nul}
#end
#ifndef (Hand_R_Object)
    #declare Hand_R_Object=object{nul}
#end
#ifndef (Hand_L_Object)
    #declare Hand_L_Object=object{nul}
#end
#ifndef (Thigh_R_Object)
    #declare Thigh_R_Object=object{nul}
#end
#ifndef (Thigh_L_Object)
    #declare Thigh_L_Object=object{nul}
#end
#ifndef (Calf_R_Object)
    #declare Calf_R_Object=object{nul}
#end
#ifndef (Calf_L_Object)
    #declare Calf_L_Object=object{nul}
#end
#ifndef (Foot_R_Object)
    #declare Foot_R_Object=object{nul}
#end
#ifndef (Foot_L_Object)
    #declare Foot_L_Object=object{nul}
#end

#if (DeBug=yes)
    #declare Head_Object=
        union {
            object{Head_Object}
            object{Vector_Locator scale 1.5}
        }
    #declare Torso_Object=object{nul}
    #declare Upperarm_R_Object=
        union {
            object {Upperarm_R_Object}
            object {Vector_Locator rotate z*90}
        }
    #declare Upperarm_L_Object=
        union {
            object {Upperarm_L_Object}
            object {Vector_Locator rotate z*90}
        }
    #declare Forearm_R_Object=
        union {
            object {Forearm_R_Object}
            object {Vector_Locator}
        }
    #declare Forearm_L_Object=
        union {
            object {Forearm_L_Object}
            object {Vector_Locator}
        }
    #declare Hand_R_Object=
        union {
            object {Hand_R_Object}
            object {Vector_Locator}
        }
    #declare Hand_L_Object=
        union {
            object {Hand_L_Object}
            object {Vector_Locator}
        }
    #declare Thigh_R_Object=
        union {
            object {Thigh_R_Object}
            object {Vector_Locator rotate z*90 scale 1.25}
        }
    #declare Thigh_L_Object=
        union {
            object {Thigh_L_Object}
            object {Vector_Locator rotate z*90 scale 1.25}
        }
    #declare Calf_R_Object=
        union {
            object {Calf_R_Object}
            object {Vector_Locator}
        }
    #declare Calf_L_Object=
        union {
            object {Calf_L_Object}
            object {Vector_Locator}
        }
    #declare Foot_R_Object=
        union {
            object {Foot_R_Object}
            cylinder {<0,-3.25,0><0,-3.0,0>6.5 pigment {rgb <1,0,0>}}
            object {Vector_Locator}
        }
    #declare Foot_L_Object=
        union {
            object {Foot_L_Object}
            cylinder {<0,-3.25,0><0,-3.0,0>6.5 pigment {rgb <1,0,0>}}
            object {Vector_Locator}
        }
#end

#version Blob_Man_Version;

//EOF